# begin: Platecom header
# -*- coding: latin-1 -*-
# vim: set ts=4 sts=4 sw=4 :
#
# $Id: config.py 306 2008-06-24 19:40:34Z flarumbe $
#
# end: Platecom header
import icsemantic.thesaurus
PROJECTNAME = "icsemantic.thesaurus"
PACKAGE = icsemantic.thesaurus
PACKAGENAME = "icsemantic.thesaurus"
DEPENDENCIES = [ 'icsemantic.core', 'icsemantic.langfallback', ]

GLOBALS = globals()
