x#footer{
	height:30px;
	vertical-align:middle;
	text-align:right;
	clear:both;
	padding-right:3px;
	background-color:#317082;
	margin-top:2px;
	width:780px;
}
#footer form{
	margin:0px;
	margin-top:2px;
}
#dhtmlgoodies_dragDropContainer{	/* Main container for this script */
	width:780px;
	border:0px
	background-color:#FFF;
	-moz-user-select:none;
}
#dhtmlgoodies_dragDropContainer ul{	/* General rules for all <ul> */
	margin-top:0px;
	margin-left:0px;
	margin-bottom:0px;
	padding:2px;
}

#dhtmlgoodies_dragDropContainer li,#dragContent li,li#indicateDestination{	/* Movable items, i.e. <LI> */
	list-style-type:none;
	height:20px;
	background-color:#EEE;
	padding:2px;
	margin-bottom:2px;
	cursor:pointer;
	display: inline;
	list-style-type: none;
	padding-right: 20px;
	white-space: nowrap;
}

li#indicateDestination{	/* Box indicating where content will be dropped - i.e. the one you use if you don't use arrow */
	border:1px solid #317082;	
	background-color:#FFF;
}
	
/* LEFT COLUMN CSS */
div#dhtmlgoodies_listOfItems{	/* Left column "Available students" */
	
	float:left;
	padding-left:0px;
	padding-right:0px;
	
	/* CSS HACK */
	width: 100%;	/* IE 5.x */
	width/* */:/**/100%;	/* Other browsers */
	width: /**/100%;
			
}
#dhtmlgoodies_listOfItems ul{	/* Left(Sources) column <ul> */
	height:100px;	

}
	
div#dhtmlgoodies_listOfItems div{
	border:1px solid #555;		
}
div#dhtmlgoodies_listOfItems div ul{	/* Left column <ul> */
	margin-left:10px;	/* Space at the left of list - the arrow will be positioned there */
}
#dhtmlgoodies_listOfItems div p{	/* Heading above left column */
	margin:0px;	
	padding-left:12px;
	background-color:#CDE2A7;	
	color:#578308;
	margin-bottom:5px;
}
/* END LEFT COLUMN CSS */

#dhtmlgoodies_dragDropContainer .mouseover{	/* Mouse over effect DIV box in right column */
	background-color:#E2EBED;
	border:1px solid #317082;
}

/* Start main container CSS */

div#dhtmlgoodies_mainContainer{	/* Right column DIV */
	width:100%;
	float:left;	
}
#dhtmlgoodies_mainContainer div{	/* Parent <div> of small boxes */
	/*float:left;*/
	margin-right:10px;
	margin-bottom:0px;
	margin-top:0px;
	border:1px solid #999;

	/* CSS HACK */
	width: 100%;	/* IE 5.x */
	width/* */:/**/100%;	/* Other browsers */
	width: /**/100%;
			
}
#dhtmlgoodies_mainContainer div ul{
	margin-left:10px;
	border:0px;
}
#dhtmlgoodies_mainContainer div ul{
	border:0px;
}

#dhtmlgoodies_mainContainer div p{	/* Term Heading*/
	margin:0px;
	padding:0px;
	padding-left:12px;
	background-color:#CDE2A7;
	color:#578308;
	text-align: left;
}

#dhtmlgoodies_mainContainer div div p{	/* Heading above small boxes */
	margin:0px;
	padding:0px;
	padding-left:12px;
	background-color:#fff;	
	color:#578308;
	text-align:left;
	padding-bottom:0px;
}

#dhtmlgoodies_mainContainer ul{	/* Small box in right column ,i.e <ul> */
	width:100%;
	border:0px;	
	margin-bottom:0px;
	overflow:hidden;
	padding:0px;
	padding-bottom:0px;
}

#dragContent{	/* Drag container */
	position:absolute;
	width:150px;
	height:20px;
	display:none;
	margin:0px;
	padding:0px;
	z-index:2000;
}

#dragDropIndicator{	/* DIV for the small arrow */
	position:absolute;
	width:7px;
	height:10px;
	display:none;
	z-index:1000;
	margin:0px;
	padding:0px;
}